@@ -86,9 +86,13 @@ class BaseSnatch:
         max_waiting_time = arrow.utcnow().shift(seconds=timeout)
         now = arrow.utcnow()
         next_check = now
+        shift_seconds = 0.1
         while now <= max_waiting_time:
             if now >= next_check:
-                next_check = arrow.utcnow().shift(seconds=1)
+                shift_seconds *= 2
+                if shift_seconds > 3:
+                    shift_seconds = 3
+                next_check = arrow.utcnow().shift(seconds=shift_seconds)
                 data = self._last_prospect(timeout=timeout)
                 if data and data.integration_status in [
                     "SUCCESS",
@@ -188,9 +192,11 @@ class BaseSnatch:
     @time_it
     def last_valid(self, tax_id: str, timeout: Optional[int] = None):
         """Return last valid DataSource integration for TaxId.
+
         It will check for the last valid Datasource Integration
         for selected TaxId. The last valid integration is the
         last one with "SUCCESS" status, regardless prospect time.
+
         :param tax_id: Valid TaxId to be prospected, with or without punctuation.
         :param timeout: Time in seconds before timeout connection. Default: 60 seconds.
         :return: DataSource Data Object
@@ -216,17 +222,22 @@ class BaseSnatch:
         max_periods_old: Optional[int] = None,
     ):
         """Get or Request DataSource Integration Data.
+
         It will:
+
         1. Check if exists a valid integration for
         selected TaxId in backend. A valid integration
         is a successfully integration (status: SUCCESS) with
         prospect date less or equal the `max_days_old` informed,
         or current period is `max_days_periods` greater than prospect period.
+
         2. If integration does not exist,
         has EXPIRED or has an status "ERROR",
         automatically start a new integration.
+
         3. If integration was started or already PENDING/RUNNING,
         wait `timeout` seconds for the backend response.
+
         :param tax_id: Valid TaxId to be prospected, with or without punctuation.
         :param max_days_old: Max days old for last integration,
                                 if exists.
